gs_quant.timeseries.statistics.min_ — gs_quant 0.1 documentation

# gs_quant.timeseries.statistics.min_

`min_`(x, w=<gs_quant.timeseries.helper.Window object>)

  Minimum value of series over given window

  Parameters

    - x (`Union`[`Series`, `List`[`Series`]]) – series: a timeseries or an array of timeseries

    - w (`Union`[`Window`, `int`, `str`]) – Window or int: size of window and ramp up to use. e.g. Window(22, 10) where 22 is the window size and 10 the ramp up value. If w is a string, it should be a relative date like ‘1m’, ‘1d’, etc. Window size defaults to length of series.

  Return type

    `Series`

  Returns

    timeseries of minimum value

  Usage

  Returns the minimum value of the series over each window.

  If \(x\) is a series:

  \(R_t = min(X_{t-w+1}:X_t)\)

  where \(w\) is the size of the rolling window.

  If \(x\) is an array of series:

  \(R_t = min(X_{1, t-w+1}:X_{n, t})\)

  where \(w\) is the size of the rolling window, and \(n\) is the number of series.

  If window is not provided, returns the minimum value over the full series. If the window size is greater than the available data, will return minimum of available values.

  Examples

  Minimum value of price series over the last \(22\) observations:

      >>> prices = generate_series(100)
      >>> min_(prices, 22)

  See also

  `max_()`